'use strict';

var foundationIcons = require('@samix-ui/foundation-icons');
var React = require('react');
var breakpoints = require('../../../../utilities/breakpoints.js');
var useEventListener = require('../../../../utilities/use-event-listener.js');
var withinContentContext = require('../../../../utilities/within-content-context.js');
var BannerExperimental$1 = require('./BannerExperimental.scss.js');
var utilities = require('./utilities.js');
var hooks = require('../../../../utilities/i18n/hooks.js');
var Text = require('../../../Text/Text.js');
var Icon = require('../../../Icon/Icon.js');
var ButtonGroup = require('../../../ButtonGroup/ButtonGroup.js');
var Button = require('../../../Button/Button.js');
var Box = require('../../../Box/Box.js');
var VerticalStack = require('../../../VerticalStack/VerticalStack.js');
var HorizontalStack = require('../../../HorizontalStack/HorizontalStack.js');

function BannerExperimental({
  status = 'info',
  icon,
  hideIcon,
  onDismiss,
  action,
  secondaryAction,
  title,
  children
}) {
  const i18n = hooks.useI18n();
  const withinContentContainer = React.useContext(withinContentContext.WithinContentContext);
  const isInlineIconBanner = !title && !withinContentContainer;
  const bannerStatus = Object.keys(utilities.bannerAttributes).includes(status) ? status : 'info';
  const bannerColors = utilities.bannerAttributes[bannerStatus][withinContentContainer ? 'withinContentContainer' : 'withinPage'];
  const sharedBannerProps = {
    backgroundColor: bannerColors.background,
    textColor: bannerColors.text,
    bannerTitle: title ? /*#__PURE__*/React.createElement(Text.Text, {
      as: "h2",
      variant: "headingSm",
      breakWord: true
    }, title) : null,
    bannerIcon: hideIcon ? null : /*#__PURE__*/React.createElement("span", {
      className: BannerExperimental$1.default[bannerColors.icon]
    }, /*#__PURE__*/React.createElement(Icon.Icon, {
      source: icon ?? utilities.bannerAttributes[bannerStatus].icon
    })),
    actionButtons: action || secondaryAction ? /*#__PURE__*/React.createElement(ButtonGroup.ButtonGroup, null, action && /*#__PURE__*/React.createElement(Button.Button, Object.assign({
      onClick: action.onAction
    }, action), action.content), secondaryAction && /*#__PURE__*/React.createElement(Button.Button, Object.assign({
      onClick: secondaryAction.onAction
    }, secondaryAction), secondaryAction.content)) : null,
    dismissButton: onDismiss ? /*#__PURE__*/React.createElement(Button.Button, {
      plain: true,
      primary: true,
      icon: /*#__PURE__*/React.createElement("span", {
        className: BannerExperimental$1.default[isInlineIconBanner ? 'icon-subdued' : bannerColors.icon]
      }, /*#__PURE__*/React.createElement(Icon.Icon, {
        source: foundationIcons.CancelMinor
      })),
      onClick: onDismiss,
      accessibilityLabel: i18n.translate('Foundation.Banner.dismissButton')
    }) : null
  };
  if (withinContentContainer) {
    return /*#__PURE__*/React.createElement(WithinContentContainerBanner, sharedBannerProps, children);
  }
  if (isInlineIconBanner) {
    return /*#__PURE__*/React.createElement(InlineIconBanner, sharedBannerProps, children);
  }
  return /*#__PURE__*/React.createElement(DefaultBanner, sharedBannerProps, children);
}
function DefaultBanner({
  backgroundColor,
  textColor,
  bannerTitle,
  bannerIcon,
  actionButtons,
  dismissButton,
  children
}) {
  const {
    smUp
  } = breakpoints.useBreakpoints();
  const hasContent = children || actionButtons;
  return /*#__PURE__*/React.createElement(Box.Box, {
    width: "100%"
  }, /*#__PURE__*/React.createElement(VerticalStack.VerticalStack, {
    align: "space-between"
  }, /*#__PURE__*/React.createElement(Box.Box, {
    background: backgroundColor,
    color: textColor,
    borderRadiusStartStart: smUp ? '3' : undefined,
    borderRadiusStartEnd: smUp ? '3' : undefined,
    borderRadiusEndStart: !hasContent && smUp ? '3' : undefined,
    borderRadiusEndEnd: !hasContent && smUp ? '3' : undefined,
    padding: "3"
  }, /*#__PURE__*/React.createElement(HorizontalStack.HorizontalStack, {
    align: "space-between",
    blockAlign: "center",
    gap: "2",
    wrap: false
  }, /*#__PURE__*/React.createElement(HorizontalStack.HorizontalStack, {
    gap: "1",
    wrap: false
  }, bannerIcon, bannerTitle), dismissButton)), hasContent && /*#__PURE__*/React.createElement(Box.Box, {
    padding: {
      xs: '3',
      md: '4'
    },
    paddingBlockStart: "3"
  }, /*#__PURE__*/React.createElement(VerticalStack.VerticalStack, {
    gap: "2"
  }, /*#__PURE__*/React.createElement("div", null, children), actionButtons))));
}
function InlineIconBanner({
  backgroundColor,
  bannerIcon,
  actionButtons,
  dismissButton,
  children
}) {
  const [blockAlign, setBlockAlign] = React.useState('center');
  const contentNode = React.useRef(null);
  const iconNode = React.useRef(null);
  const handleResize = React.useCallback(() => {
    const contentHeight = contentNode.current?.offsetHeight;
    const iconBoxHeight = iconNode.current?.offsetHeight;
    if (!contentHeight || !iconBoxHeight) return;
    contentHeight > iconBoxHeight ? setBlockAlign('start') : setBlockAlign('center');
  }, []);
  React.useEffect(() => handleResize(), [handleResize]);
  useEventListener.useEventListener('resize', handleResize);
  return /*#__PURE__*/React.createElement(Box.Box, {
    width: "100%",
    padding: "3",
    borderRadius: "3"
  }, /*#__PURE__*/React.createElement(HorizontalStack.HorizontalStack, {
    align: "space-between",
    blockAlign: blockAlign,
    wrap: false
  }, /*#__PURE__*/React.createElement(Box.Box, {
    width: "100%"
  }, /*#__PURE__*/React.createElement(HorizontalStack.HorizontalStack, {
    gap: "2",
    wrap: false,
    blockAlign: blockAlign
  }, /*#__PURE__*/React.createElement("div", {
    ref: iconNode
  }, /*#__PURE__*/React.createElement(Box.Box, {
    background: backgroundColor,
    borderRadius: "2",
    padding: "1"
  }, bannerIcon)), /*#__PURE__*/React.createElement(Box.Box, {
    ref: contentNode,
    width: "100%"
  }, /*#__PURE__*/React.createElement(VerticalStack.VerticalStack, {
    gap: "2"
  }, /*#__PURE__*/React.createElement("div", null, children), actionButtons)))), dismissButton));
}
function WithinContentContainerBanner({
  backgroundColor,
  textColor,
  bannerTitle,
  bannerIcon,
  actionButtons,
  dismissButton,
  children
}) {
  return /*#__PURE__*/React.createElement(Box.Box, {
    width: "100%",
    background: backgroundColor,
    padding: "2",
    borderRadius: "2",
    color: textColor
  }, /*#__PURE__*/React.createElement(HorizontalStack.HorizontalStack, {
    align: "space-between",
    blockAlign: "start",
    wrap: false
  }, /*#__PURE__*/React.createElement(HorizontalStack.HorizontalStack, {
    gap: "1_5-experimental",
    wrap: false
  }, bannerIcon, /*#__PURE__*/React.createElement(Box.Box, {
    width: "100%"
  }, /*#__PURE__*/React.createElement(VerticalStack.VerticalStack, {
    gap: "2"
  }, /*#__PURE__*/React.createElement(VerticalStack.VerticalStack, {
    gap: "05"
  }, bannerTitle, /*#__PURE__*/React.createElement("div", null, children)), actionButtons))), dismissButton));
}

exports.BannerExperimental = BannerExperimental;
