'use strict';

var foundationIcons = require('@samix-ui/foundation-icons');
var React$1 = require('react');
var FilterButton = require('../FilterButton/FilterButton.js');
var ChoiceList = require('../../../ChoiceList/ChoiceList.js');
var DirectionButton = require('./components/DirectionButton/DirectionButton.js');
var hooks = require('../../../../utilities/i18n/hooks.js');
var hooks$1 = require('../../../../utilities/features/hooks.js');
var Tooltip = require('../../../Tooltip/Tooltip.js');
var Popover = require('../../../Popover/Popover.js');
var Box = require('../../../Box/Box.js');
var Icon = require('../../../Icon/Icon.js');

exports.SortButtonDirection = void 0;
(function (SortButtonDirection) {
  SortButtonDirection["Asc"] = "asc";
  SortButtonDirection["Desc"] = "desc";
})(exports.SortButtonDirection || (exports.SortButtonDirection = {}));
function SortButton({
  choices,
  selected,
  onChange,
  disabled,
  onChangeKey,
  onChangeDirection
}) {
  const i18n = hooks.useI18n();
  const {
    foundationSummerEditions2023
  } = hooks$1.useFeatures();
  const [active, setActive] = React$1.useState(false);
  const [selectedValueKey, selectedDirection] = selected[0].split(' ');
  function handleClick() {
    setActive(pastActive => !pastActive);
  }
  function handleClose() {
    setActive(false);
  }
  function handleChangeChoiceList(sel) {
    if (onChangeKey) {
      const [key] = sel[0].split(' ');
      onChangeKey(key);
    } else {
      onChange(sel);
    }
  }
  function handleChangeDirection(sel) {
    if (onChangeDirection) {
      const [, direction] = sel[0].split(' ');
      onChangeDirection(direction);
    } else {
      onChange(sel);
    }
  }
  const choiceListChoices = React$1.useMemo(() => {
    const choiceCategories = choices.reduce((acc, curr) => {
      const alreadyExists = acc.some(option => option.label === curr.label);
      const [, currentValueDirection] = curr.value.split(' ');
      const isSameDirection = currentValueDirection === selectedDirection;
      if (!alreadyExists) {
        return [...acc, curr];
      }
      if (isSameDirection) {
        return acc.map(option => {
          if (option.label === curr.label) {
            return curr;
          }
          return option;
        });
      }
      return acc;
    }, []);
    return choiceCategories;
  }, [choices, selectedDirection]);
  const selectedChoices = choices.filter(choice => {
    const [currentKey] = choice.value.split(' ');
    return currentKey === selectedValueKey;
  });
  const iconMarkup = foundationSummerEditions2023 ? foundationIcons.SortMinor : undefined;
  const childMarkup = !foundationSummerEditions2023 ? /*#__PURE__*/React.createElement(Icon.Icon, {
    source: foundationIcons.SortMinor,
    color: "base"
  }) : null;
  const sortButton = /*#__PURE__*/React.createElement(Tooltip.Tooltip, {
    content: i18n.translate('Foundation.IndexFilters.SortButton.tooltip'),
    preferredPosition: "above",
    hoverDelay: 400
  }, /*#__PURE__*/React.createElement(FilterButton.FilterButton, {
    icon: iconMarkup,
    onClick: handleClick,
    label: i18n.translate('Foundation.IndexFilters.SortButton.ariaLabel'),
    disabled: disabled
  }, childMarkup));
  return /*#__PURE__*/React.createElement(Popover.Popover, {
    active: active && !disabled,
    activator: sortButton,
    autofocusTarget: "first-node",
    onClose: handleClose,
    preferredAlignment: "right",
    fluidContent: true
  }, /*#__PURE__*/React.createElement(Box.Box, {
    minWidth: "148px",
    padding: foundationSummerEditions2023 ? undefined : '4',
    paddingInlineStart: foundationSummerEditions2023 ? '3' : undefined,
    paddingInlineEnd: foundationSummerEditions2023 ? '3' : undefined,
    paddingBlockStart: foundationSummerEditions2023 ? '2' : undefined,
    paddingBlockEnd: foundationSummerEditions2023 ? '2' : undefined,
    borderBlockEndWidth: "1",
    borderColor: "border-subdued"
  }, /*#__PURE__*/React.createElement(ChoiceList.ChoiceList, {
    title: i18n.translate('Foundation.IndexFilters.SortButton.title'),
    choices: choiceListChoices,
    selected: selected,
    onChange: handleChangeChoiceList
  })), /*#__PURE__*/React.createElement(Box.Box, {
    padding: foundationSummerEditions2023 ? undefined : '4',
    paddingInlineStart: foundationSummerEditions2023 ? '1_5-experimental' : undefined,
    paddingInlineEnd: foundationSummerEditions2023 ? '1_5-experimental' : undefined,
    paddingBlockStart: foundationSummerEditions2023 ? '2' : undefined,
    paddingBlockEnd: foundationSummerEditions2023 ? '2' : undefined
  }, /*#__PURE__*/React.createElement(DirectionButton.DirectionButton, {
    direction: "asc",
    active: selectedDirection === exports.SortButtonDirection.Asc,
    onClick: handleChangeDirection,
    value: selectedChoices?.[0]?.value
  }, selectedChoices?.[0]?.directionLabel), /*#__PURE__*/React.createElement(DirectionButton.DirectionButton, {
    direction: "desc",
    active: selectedDirection === exports.SortButtonDirection.Desc,
    onClick: handleChangeDirection,
    value: selectedChoices?.[1]?.value
  }, selectedChoices?.[1]?.directionLabel)));
}

exports.SortButton = SortButton;
