'use strict';

var React$1 = require('react');
var focus = require('../../../../utilities/focus.js');
var useIsTouchDevice = require('../../../../utilities/use-is-touch-device.js');
var hooks = require('../../../../utilities/i18n/hooks.js');
var hooks$1 = require('../../../../utilities/features/hooks.js');
var Button = require('../../../Button/Button.js');
var HorizontalStack = require('../../../HorizontalStack/HorizontalStack.js');
var Modal = require('../../../Modal/Modal.js');
var Form = require('../../../Form/Form.js');
var FormLayout = require('../../../FormLayout/FormLayout.js');
var TextField = require('../../../TextField/TextField.js');

const MAX_VIEW_NAME_LENGTH = 40;
function UpdateButtons({
  primaryAction,
  cancelAction,
  viewNames,
  disabled
}) {
  const i18n = hooks.useI18n();
  const [savedViewName, setSavedViewName] = React$1.useState('');
  const [savedViewModalOpen, setSavedViewModalOpen] = React$1.useState(false);
  const container = React$1.useRef(null);
  const isTouchDevice = useIsTouchDevice.useIsTouchDevice();
  const {
    foundationSummerEditions2023: se23
  } = hooks$1.useFeatures();
  React$1.useEffect(() => {
    if (!container.current || isTouchDevice) return;
    if (savedViewModalOpen) {
      focus.focusFirstFocusableNode(container.current);
    }
  }, [savedViewModalOpen, isTouchDevice]);
  async function handleClickSaveButton() {
    if (primaryAction?.type === 'save-as') {
      handleOpenModal();
    } else {
      await primaryAction?.onAction('');
    }
  }
  function handleOpenModal() {
    setSavedViewModalOpen(true);
  }
  function handleCloseModal() {
    setSavedViewModalOpen(false);
  }
  function handleChange(value) {
    setSavedViewName(value);
  }
  async function handlePrimaryAction() {
    if (isPrimaryActionDisabled) return;
    await primaryAction?.onAction(savedViewName);
    handleCloseModal();
  }
  const buttonText = React$1.useMemo(() => {
    switch (primaryAction?.type) {
      case 'save':
        return i18n.translate('Foundation.IndexFilters.UpdateButtons.save');
      case 'save-as':
      default:
        return i18n.translate('Foundation.IndexFilters.UpdateButtons.saveAs');
    }
  }, [primaryAction?.type, i18n]);
  const saveButton = /*#__PURE__*/React.createElement(Button.Button, {
    size: "micro",
    primary: !se23 ? true : undefined,
    plain: !se23 ? true : undefined,
    onClick: handleClickSaveButton,
    disabled: primaryAction?.disabled || disabled
  }, buttonText);
  const hasSameNameError = viewNames.some(name => name.trim().toLowerCase() === savedViewName.trim().toLowerCase());
  const isPrimaryActionDisabled = hasSameNameError || !savedViewName || primaryAction?.loading || savedViewName.length > MAX_VIEW_NAME_LENGTH;
  const cancelButtonMarkup = /*#__PURE__*/React.createElement(Button.Button, {
    plain: true,
    primary: se23 ? true : undefined,
    size: "micro",
    onClick: cancelAction.onAction,
    disabled: disabled
  }, i18n.translate('Foundation.IndexFilters.UpdateButtons.cancel'));
  if (!primaryAction) {
    return cancelButtonMarkup;
  }
  return /*#__PURE__*/React.createElement(HorizontalStack.HorizontalStack, {
    align: "start",
    blockAlign: "center",
    gap: se23 ? '1' : '2'
  }, cancelButtonMarkup, primaryAction.type === 'save-as' ? /*#__PURE__*/React.createElement(Modal.Modal, {
    activator: /*#__PURE__*/React.createElement(HorizontalStack.HorizontalStack, null, saveButton),
    open: savedViewModalOpen,
    title: i18n.translate('Foundation.IndexFilters.UpdateButtons.modal.title'),
    onClose: handleCloseModal,
    primaryAction: {
      onAction: handlePrimaryAction,
      content: i18n.translate('Foundation.IndexFilters.UpdateButtons.modal.save'),
      disabled: isPrimaryActionDisabled
    },
    secondaryActions: [{
      onAction: handleCloseModal,
      content: i18n.translate('Foundation.IndexFilters.UpdateButtons.modal.cancel')
    }]
  }, /*#__PURE__*/React.createElement(Modal.Modal.Section, null, /*#__PURE__*/React.createElement(Form.Form, {
    onSubmit: handlePrimaryAction
  }, /*#__PURE__*/React.createElement(FormLayout.FormLayout, null, /*#__PURE__*/React.createElement("div", {
    ref: container
  }, /*#__PURE__*/React.createElement(TextField.TextField, {
    label: i18n.translate('Foundation.IndexFilters.UpdateButtons.modal.label'),
    value: savedViewName,
    onChange: handleChange,
    autoComplete: "off",
    maxLength: MAX_VIEW_NAME_LENGTH,
    showCharacterCount: true,
    error: hasSameNameError ? i18n.translate('Foundation.IndexFilters.UpdateButtons.modal.sameName', {
      name: savedViewName
    }) : undefined
  })))))) : saveButton);
}

exports.UpdateButtons = UpdateButtons;
