import { SortMinor } from '@samix-ui/foundation-icons';
import { useState, useMemo } from 'react';
import { FilterButton } from '../FilterButton/FilterButton.js';
import { ChoiceList } from '../../../ChoiceList/ChoiceList.js';
import { DirectionButton } from './components/DirectionButton/DirectionButton.js';
import { useI18n } from '../../../../utilities/i18n/hooks.js';
import { useFeatures } from '../../../../utilities/features/hooks.js';
import { Tooltip } from '../../../Tooltip/Tooltip.js';
import { Popover } from '../../../Popover/Popover.js';
import { Box } from '../../../Box/Box.js';
import { Icon } from '../../../Icon/Icon.js';

let SortButtonDirection;
(function (SortButtonDirection) {
  SortButtonDirection["Asc"] = "asc";
  SortButtonDirection["Desc"] = "desc";
})(SortButtonDirection || (SortButtonDirection = {}));
function SortButton({
  choices,
  selected,
  onChange,
  disabled,
  onChangeKey,
  onChangeDirection
}) {
  const i18n = useI18n();
  const {
    foundationSummerEditions2023
  } = useFeatures();
  const [active, setActive] = useState(false);
  const [selectedValueKey, selectedDirection] = selected[0].split(' ');
  function handleClick() {
    setActive(pastActive => !pastActive);
  }
  function handleClose() {
    setActive(false);
  }
  function handleChangeChoiceList(sel) {
    if (onChangeKey) {
      const [key] = sel[0].split(' ');
      onChangeKey(key);
    } else {
      onChange(sel);
    }
  }
  function handleChangeDirection(sel) {
    if (onChangeDirection) {
      const [, direction] = sel[0].split(' ');
      onChangeDirection(direction);
    } else {
      onChange(sel);
    }
  }
  const choiceListChoices = useMemo(() => {
    const choiceCategories = choices.reduce((acc, curr) => {
      const alreadyExists = acc.some(option => option.label === curr.label);
      const [, currentValueDirection] = curr.value.split(' ');
      const isSameDirection = currentValueDirection === selectedDirection;
      if (!alreadyExists) {
        return [...acc, curr];
      }
      if (isSameDirection) {
        return acc.map(option => {
          if (option.label === curr.label) {
            return curr;
          }
          return option;
        });
      }
      return acc;
    }, []);
    return choiceCategories;
  }, [choices, selectedDirection]);
  const selectedChoices = choices.filter(choice => {
    const [currentKey] = choice.value.split(' ');
    return currentKey === selectedValueKey;
  });
  const iconMarkup = foundationSummerEditions2023 ? SortMinor : undefined;
  const childMarkup = !foundationSummerEditions2023 ? /*#__PURE__*/React.createElement(Icon, {
    source: SortMinor,
    color: "base"
  }) : null;
  const sortButton = /*#__PURE__*/React.createElement(Tooltip, {
    content: i18n.translate('Foundation.IndexFilters.SortButton.tooltip'),
    preferredPosition: "above",
    hoverDelay: 400
  }, /*#__PURE__*/React.createElement(FilterButton, {
    icon: iconMarkup,
    onClick: handleClick,
    label: i18n.translate('Foundation.IndexFilters.SortButton.ariaLabel'),
    disabled: disabled
  }, childMarkup));
  return /*#__PURE__*/React.createElement(Popover, {
    active: active && !disabled,
    activator: sortButton,
    autofocusTarget: "first-node",
    onClose: handleClose,
    preferredAlignment: "right",
    fluidContent: true
  }, /*#__PURE__*/React.createElement(Box, {
    minWidth: "148px",
    padding: foundationSummerEditions2023 ? undefined : '4',
    paddingInlineStart: foundationSummerEditions2023 ? '3' : undefined,
    paddingInlineEnd: foundationSummerEditions2023 ? '3' : undefined,
    paddingBlockStart: foundationSummerEditions2023 ? '2' : undefined,
    paddingBlockEnd: foundationSummerEditions2023 ? '2' : undefined,
    borderBlockEndWidth: "1",
    borderColor: "border-subdued"
  }, /*#__PURE__*/React.createElement(ChoiceList, {
    title: i18n.translate('Foundation.IndexFilters.SortButton.title'),
    choices: choiceListChoices,
    selected: selected,
    onChange: handleChangeChoiceList
  })), /*#__PURE__*/React.createElement(Box, {
    padding: foundationSummerEditions2023 ? undefined : '4',
    paddingInlineStart: foundationSummerEditions2023 ? '1_5-experimental' : undefined,
    paddingInlineEnd: foundationSummerEditions2023 ? '1_5-experimental' : undefined,
    paddingBlockStart: foundationSummerEditions2023 ? '2' : undefined,
    paddingBlockEnd: foundationSummerEditions2023 ? '2' : undefined
  }, /*#__PURE__*/React.createElement(DirectionButton, {
    direction: "asc",
    active: selectedDirection === SortButtonDirection.Asc,
    onClick: handleChangeDirection,
    value: selectedChoices?.[0]?.value
  }, selectedChoices?.[0]?.directionLabel), /*#__PURE__*/React.createElement(DirectionButton, {
    direction: "desc",
    active: selectedDirection === SortButtonDirection.Desc,
    onClick: handleChangeDirection,
    value: selectedChoices?.[1]?.value
  }, selectedChoices?.[1]?.directionLabel)));
}

export { SortButton, SortButtonDirection };
